@@ -16,6 +16,9 @@ use warnings;
 
 use Carp;
 use Scalar::Util 'blessed';
+use WebService::AbuseIPDB;
+
+our $VERSION = $WebService::AbuseIPDB::VERSION;
 
 my %by_id = (
 	3 	=> 'Fraud Orders',
